# eric7.CondaInterface.CondaExecDialog

Module implementing a dialog to show the output of a conda execution.

### Global Attributes

None

### Classes

CondaExecDialog | Class implementing a dialog to show the output of a conda execution.

### Functions

None

## CondaExecDialog

Class implementing a dialog to show the output of a conda execution.

### Derived from

QDialog, Ui_CondaExecDialog

### Class Attributes

None

### Class Methods

None

### Methods

CondaExecDialog | Constructor
__finish | Private slot called when the process finished.
__logError | Private method to log an error.
__logOutput | Private method to log some output.
__readStderr | Private slot to handle the readyReadStandardError signal.
__readStdout | Private slot to handle the readyReadStandardOutput signal.
__setProgressValues | Private method to set the value of the progress bar.
getResult | Public method to the result of the command execution.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the conda command.

### Static Methods

None

#### CondaExecDialog (Constructor)

CondaExecDialog(command, parent=None)

Constructor

command (str)
  conda command executed
parent (QWidget)
  reference to the parent widget

#### CondaExecDialog.__finish

__finish(exitCode, _exitStatus)

Private slot called when the process finished.

It is called when the process finished or the user pressed the button.

exitCode (int)
  exit code of the process
_exitStatus (QProcess.ExitStatus)
  exit status of the process (unused)

#### CondaExecDialog.__logError

__logError(stderr)

Private method to log an error.

stderr (str)
  error string to log

#### CondaExecDialog.__logOutput

__logOutput(stdout)

Private method to log some output.

stdout (str)
  output string to log

#### CondaExecDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStandardError signal.

It reads the error output of the process and inserts it into the error pane.

#### CondaExecDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStandardOutput signal.

It reads the output of the process, formats it and inserts it into the contents pane.

#### CondaExecDialog.__setProgressValues

__setProgressValues(jsonDict, progressType)

Private method to set the value of the progress bar.

jsonDict (dict)
  dictionary containing the progress info
progressType (str)
  action type to check for

Return:
  flag indicating success

Return Type:
  bool

#### CondaExecDialog.getResult

getResult()

Public method to the result of the command execution.

Return:
  tuple containing a flag indicating success and the result data.

Return Type:
  tuple of (bool, dict)

#### CondaExecDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### CondaExecDialog.start

start(arguments)

Public slot to start the conda command.

arguments (list of str)
  commandline arguments for conda program

Up